#include <Arduino.h>
#include <Adafruit_GFX.h>
#include <Adafruit_ILI9341.h>

#define TFT_CLK 13   // Пин SCL (Serial Clock) для TFT
#define TFT_MISO 12  // Пин SDO (Serial Data Out) для TFT, не используется
#define TFT_MOSI 11  // Пин SDI (Serial Data In) для TFT
#define TFT_CS 10    // Пин Chip Select для TFT
#define TFT_DC 9     // Пин Data/Command для TFT
#define TFT_RST 8    // Пин Reset для TFT

Adafruit_ILI9341 tft = Adafruit_ILI9341(TFT_CS, TFT_DC, TFT_RST, TFT_CLK, TFT_RST);

int ecgPin = A0;  // Подключите OUTPUT модуля AD8232 к аналоговому входу A0
int ecgData[320]; // Массив для хранения данных ЭКГ

void setup() {
  Serial.begin(115200); // Настройка последовательной связи для отправки данных на компьютер
  tft.begin();
  tft.setRotation(3);  // Повернуть экран, если необходимо
  tft.fillScreen(ILI9341_BLACK);
  tft.setTextColor(ILI9341_WHITE);
  tft.setTextSize(2);
  tft.setCursor(0, 0);
  tft.println("ESP32 ECG Monitor");
  tft.println("Reading ECG values...");
}

void loop() {
  for (int i = 0; i < 320; i++) {
    int ecgValue = analogRead(ecgPin); // Считывается значение с аналогового входа
    ecgData[i] = ecgValue; // Сохраняются данные ЭКГ в массиве
    delay(50); // Задержка для стабилизации считанных данных
  }
  
  // Отображаются данные графика на TFT-экране
  tft.fillScreen(ILI9341_BLACK);
  tft.drawLine(0, 120, 319, 120, ILI9341_WHITE); // Горизонтальная линия
  for (int i = 1; i < 320; i++) {
    tft.drawLine(i - 1, map(ecgData[i - 1], 0, 4095, 240, 0), i, map(ecgData[i], 0, 4095, 240, 0), ILI9341_YELLOW);
  }
}
 

 // код для датчика Пульсоксиметра

#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_MAX3010x.h>
#include <LiquidCrystal.h>

LiquidCrystal lcd(0);

Adafruit_MAX3010x pulseOx;

void setup(void)
{
  lcd.begin(16, 2);
  lcd.print("Pulse and SpO2");

  // Инициализация датчика MAX30102
  if (!pulseOx.begin(Wire, I2C_SPEED_FAST)) {
    lcd.clear();
    lcd.print("MAX30102 not found!");
    while (1);
  }
}

void loop(void)
{
  lcd.setCursor(0, 1);

  if (pulseOx.available()) {
    float bpm, spo2;
    pulseOx.read(&bpm, &spo2);

    lcd.print("BPM: ");
    lcd.print(bpm);
    lcd.print("   ");

    lcd.print("SpO2: ");
    lcd.print(spo2);
    lcd.print("%   ");
  }
}

